@@ -148,6 +148,37 @@ class ToscaTemplateTest(TestCase):
         self.assertFalse(
             wordpress_node.is_derived_from("tosca.policies.Root"))
 
+    def test_nodetype_without_relationship(self):
+        # Nodes that contain "relationship" in "requirements"
+        depend_node_types = (
+            "tosca.nodes.SoftwareComponent",
+        )
+
+        # Nodes that do not contain "relationship" in "requirements"
+        non_depend_node_types = (
+            "tosca.nodes.Compute",
+            "sample.SC",
+        )
+
+        tosca_tpl = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            "data/test_nodetype_without_relationship.yaml")
+        tosca = ToscaTemplate(tosca_tpl)
+
+        nodetemplates = tosca.nodetemplates
+        for node in nodetemplates:
+            node_depend = node.related_nodes
+            if node_depend:
+                self.assertIn(
+                    node.type,
+                    depend_node_types
+                )
+            else:
+                self.assertIn(
+                    node.type,
+                    non_depend_node_types
+                )
+
     def test_outputs(self):
         self.assertEqual(
             ['website_url'],
@@ -303,17 +334,17 @@ class ToscaTemplateTest(TestCase):
                     relation, node in node_tpl.relationships.items()])
                 self.assertEqual(expected_relationship, actual_relationship)
             if node_tpl.name == 'mysql_database':
-                    self.assertEqual(
-                        [('tosca.relationships.HostedOn', 'my_dbms')],
-                        [(relation.type, node.name) for
-                         relation,
-                         node in node_tpl.relationships.items()])
+                self.assertEqual(
+                    [('tosca.relationships.HostedOn', 'my_dbms')],
+                    [(relation.type, node.name) for
+                     relation,
+                     node in node_tpl.relationships.items()])
             if node_tpl.name == 'my_server':
-                    self.assertEqual(
-                        [('tosca.relationships.AttachesTo', 'my_storage')],
-                        [(relation.type, node.name) for
-                         relation,
-                         node in node_tpl.relationships.items()])
+                self.assertEqual(
+                    [('tosca.relationships.AttachesTo', 'my_storage')],
+                    [(relation.type, node.name) for
+                     relation,
+                     node in node_tpl.relationships.items()])
 
     def test_template_requirements_not_implemented(self):
         # TODO(spzala): replace this test with new one once TOSCA types look up
@@ -951,3 +982,27 @@ class ToscaTemplateTest(TestCase):
             os.path.dirname(os.path.abspath(__file__)),
             'data/CSAR/csar_relative_path_import_check.zip')
         self.assertTrue(ToscaTemplate(csar_archive))
+
+    def test_csar_multiple_deployment_flavours(self):
+        csar_archive = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            'data/CSAR/csar_multiple_deployment_flavour.zip')
+        tosca = ToscaTemplate(csar_archive)
+        flavours = list()
+        for tp in tosca.nested_tosca_templates_with_topology:
+            flavour_id = tp.substitution_mappings.properties.get('flavour_id')
+            flavour = {'flavour_id': flavour_id}
+            flavours.append(flavour)
+        self.assertEqual(flavours[0]['flavour_id'], 'simple')
+        self.assertEqual(flavours[1]['flavour_id'], 'complex')
+
+    def test_custom_rel_get_type(self):
+        tosca_tpl = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            "data/test_tosca_custom_rel.yaml")
+        tosca = ToscaTemplate(tosca_tpl)
+        for src in tosca.nodetemplates:
+            for rel, trgt in src.relationships.items():
+                rel_tpls = trgt.get_relationship_template()
+
+        self.assertEqual(rel_tpls[0].type, "MyAttachesTo")
